class StockOrdersController < ApplicationController
  model_data_store(StockOrder)

  def submit
    @model = StockOrder.find(params[:id])
    data = @model.as_json({:include => [:stock_order_items]})

    order_number = Order.submit_stock_order!(data)

    @model.update(order_number: order_number, status: 'closed', date_completed: DateTime.now)
    render json: @model, status: :created, location: @model
  end

  private
    # Only allow a list of trusted parameters through.
    def model_params
      params.require(:stock_order).permit(:id, :status, :date_completed, :date_ordered, :order_number, :po_number, :reference_number, :created_at, :updated_at, :customer_id, :shipping_method_id, :user_id, :release_number)
    end

  def before_sort(sort)
    if sort[:id] == "shipping_method_code"
      sort[:id] = "shipping_methods.code"
    end
    sort
  end

  def before_filter(filter)
    if filter[:id] == 'customer_id'
      filter[:strict_match] = true
      filter[:value] = filter[:value].split('|')
    end

    if filter[:id] == "shipping_method_code"
      filter[:id] = "shipping_methods.code"
    end
    filter
  end

  def before_set_targets
    @models = if RxModule::Authorization.current_user_can?('config', 'user_config_admin')
                @models
              else
                config = Config.find_by(user_id: RxModule::Authorization.current_user[:id])
                @models = @models.where(customer_id: config.config_customers.map(&:customer_id))
              end
    @models.eager_load(:shipping_method)
  end
end
