// @ts-ignore
import debounce from 'debounce-async';
import {Transport} from "@rx-suite/data";

/**
 * This class exists because we need to track the previous value of the PO number.
 * If we didn't yup would perform the deboucne on every keystroke, which would cause a
 * 250ms delay on all data entry before validations were processed.
 *
 * Note that this class only supports a single po validation. If we every need to validate
 * multiple POs on the same page (I don't know why this would come up), then we would forgo using the
 * singleton pattern and instead create a new instance of this class for each PO.
 */
export class PoValidator {
    static _instance: PoValidator;

    lastPoNumber? = "";
    lastPoResult = false;

    static get instance() {
        if (!PoValidator._instance) {
            PoValidator._instance = new PoValidator();
        }
        return PoValidator._instance;
    }

    async validate(poNumber?: string, customerId?: string) {
        if(!poNumber) {
            this.lastPoNumber = poNumber;
            this.lastPoResult = true;
            return true;
        }

        if(this.lastPoNumber === poNumber) {
            return this.lastPoResult;
        }


        this.lastPoNumber = poNumber;

        const result = await this.debouncedCheckDuplicate(poNumber, customerId);

        // If the po number changed before we finished our duplicate check,
        // trust the last result
        if(this.lastPoNumber !== poNumber) {
            return this.lastPoResult;
        }

        this.lastPoResult = result;

        return result;
    }

    async checkDuplicate(poNumber: string, customerId: string) {
        const response = await Transport.fetch(`/api/orders/duplicate?po_number=${encodeURIComponent(poNumber)}&customer_id=${encodeURIComponent(customerId)}`);
        const json = await response.json()
        return !json.result
    }

    debouncedCheckDuplicate = debounce(this.checkDuplicate, 500);
}