import * as React from 'react';
import {observer} from "mobx-react-lite";
import {InputField, useModelContext, useReadonlyContext} from "@rx-suite/ui";

import {OrderFieldProps} from "../../../stores/_FieldConstants";
import {getLeftName} from "../../../hooks/useOrderEntryStore";


export const BalanceAxisField: React.FunctionComponent<OrderFieldProps> = observer(({
                                                                                        name,
                                                                                        label,
                                                                                        disabled,
                                                                                        eye
                                                                                    }) => {
    const model = useModelContext();
    const readOnly = useReadonlyContext();

    const handleEyeFieldBlur = React.useCallback(() => {
        if (eye === "rt") {
            const leftName = getLeftName(name);
            if (!model.viewModel.dig(leftName)) {
                const currVal = model.viewModel.dig(name);
                const newVal = 180 - currVal;
                model.nestedAssignment(leftName, newVal);
            }
        }

        model.validate();
    }, [model, eye, name]);

    const handleEyeFieldChange = React.useCallback(e => {
        model.nestedAssignment(e.target.name, e.target.value);
    }, [model]);

    return (
        <InputField
            disabled={disabled || readOnly}
            label={label}
            name={name}
            value={model.viewModel.dig(name)}
            onChange={handleEyeFieldChange}
            onBlur={handleEyeFieldBlur}
            error={!disabled && !!model.errors[name]}
            helperText={model.errors[name]}
            fullWidth
        />
    )
});