import * as React from 'react';
import {Conditional, IfFalse, IfTrue, ModelInput, useModelContext} from "@rx-suite/ui";
import {Grid} from "@material-ui/core";
import {ShippingMethodModel, ShippingMethodStore} from "../../../stores/ShippingMethodStore";
import {observer} from "mobx-react-lite";
import {RxUniverseStore} from "../../../stores/RxUniverseStore";
// @ts-ignore
import {City, Country, State} from 'country-state-city';
import {StateCitySelect} from "./StateCitySelect";
import {LabMaintenanceStore} from "../../../stores/LabMaintenanceStore";
import {AddressField} from "./AddressField";

export const ShippingFields = observer(() => {
    const model = useModelContext();
    const rxu_config = RxUniverseStore.selectedModel;
    const [isShipToRequired, setIsShipToRequired] = React.useState(false);

    React.useEffect(() => {
        const ship_method_id = model.viewModel.shipping_method_id as string;
        const shipping_method = ShippingMethodStore.get(ship_method_id) as ShippingMethodModel;
        const ship_to_required = shipping_method?.ship_to_required || false;
        setIsShipToRequired(ship_to_required);
    }, [model.viewModel.shipping_method_id])

    if(!isShipToRequired && !LabMaintenanceStore.selectedModel?.display_addresses) {
        return null;
    }

    return (
        <>
            <Grid item xs={4}>
                <ModelInput name={"ship_to_name"}/>
            </Grid>
            <Grid item xs={12} lg={12}>
                <Grid container spacing={4}>
                    <Grid item xs={4}>
                        <AddressField name={"ship_to_address1"}/>
                    </Grid>
                    <Grid item xs={4}>
                        <AddressField name={"ship_to_address2"}/>
                    </Grid>
                </Grid>
                <Grid container spacing={4}>
                    <Conditional condition={rxu_config.cityState}>
                        <IfTrue>
                            <StateCitySelect/>
                        </IfTrue>
                        <IfFalse>
                            <Grid item xs={4}>
                                <AddressField name={"ship_to_address3"}/>
                            </Grid>
                            <Grid item xs={4}>
                                <AddressField name={"ship_to_address4"}/>
                            </Grid>
                        </IfFalse>
                    </Conditional>
                </Grid>
            </Grid>
        </>
    )
});
