import {attribute, DataStore, model, Model} from '@rx-suite/data/build';
import {t} from "@lingui/macro";

@model({
    singleton: true,
    eager: true,
    permissionTarget: "LabMaintenance",
    transportLayer: "/api/lab_maintenance",
    routingInfo: {
        update: "/lab_maintenance/edit",
        read: "/lab_maintenance"
    }
})
export class LabMaintenanceModel extends Model {

    constructor() {
        super();
        super.setup();
    }

    @attribute({
        label: t`Lab Id`,
        description: t`Unique identifier of the lab that the settings is applied`,
    })
    lab_id?: string | null = null;

    @attribute({
        label: t`Always Display Addresses?`,
        description: t`Show/hide addresses`,
    })
    display_addresses?: boolean = false;

    @attribute({
        label: t`Display Wanted Date?`,
        description: t`Show/hide wanted date information`
    })
    display_wanted_date?: boolean = false;

    @attribute({
        label: t`Display Hold Switch?`,
        description: t`Show/hide hold switch`
    })
    display_hold_switch?: boolean = false;

    @attribute({
        label: t`Display Uncut Orders?`,
        description: t`Show/hide uncut orders`
    })
    display_uncut_orders?: boolean = false;

    @attribute({
        label: t`Split Name On Order Entry?`,
        description: t`Allow name separation during Order Entry`
    })
    split_name_on_order_entry?: boolean = false;

    @attribute({
        label: t`Confirmation Template`,
        description: t`Which XML template to use when generating confirmation page`
    })
    confirmation_template = "";

    @attribute({
        label: t`Display Shipping Info`,
        description: t`Show/hide shipping information`
    })
    display_shipping_info = true;

    @attribute({
        label: t`Display quick codes`,
        description: t`Show/hide quick codes`
    })
    display_quick_codes = true;

}

export const LabMaintenanceStore = LabMaintenanceModel.store as unknown as DataStore<LabMaintenanceModel>;
