import {attribute, DataStore, model, Model} from "@rx-suite/data";
import {t} from "@lingui/macro";
import {computed} from "mobx";
import * as yup from 'yup';

@model({
    transportLayer: "/api/quick_codes",
    permissionTarget: "QuickCode",
    eager: true,
    routingInfo: {
        list: '/quick_codes',
        create: '/quick_codes/create',
        read: '/quick_codes/:id/read',
        update: '/quick_codes/:id/edit',
        delete: '/quick_codes/:id/delete'
    }
})
export class QuickCodeModel extends Model {
    constructor() {
        super();
        super.setup();
    }

    @attribute({label: t`Quick Code`, validation: yup.number().max(99999999999).min(0).typeError(t`Must be a valid number`).integer()})
    code: number | null = null;

    @attribute({label: t`Type`})
    style_type_id: string | null = null;

    @attribute({label: t`Style`})
    style_id: string | null = null;

    @attribute({label: t`Material`})
    style_material_id: string | null = null;

    @attribute()
    style_type_name = "";

    @attribute()
    style_name = "";

    @attribute()
    style_material_name = "";

    @computed
    get displayName() {
        return `${this.code} - ${this.style_name} ${this.style_type_name} ${this.style_material_name}`
    }
}

export const QuickCodeStore = QuickCodeModel.store as unknown as DataStore<QuickCodeModel>;