class SyncStyleMaterialsJob < ApplicationJob
  queue_as :default

  def perform(*args)
    StyleMaterialSyncStatus.wrap do
      offset = 0

      style_ids = []
      last_response = nil
      loop do
        rxu_mats = RxModule::Communicator::Rxuniverse.style_materials(limit: SyncStatus::LIMIT, offset: offset)

        break if rxu_mats.empty? || rxu_mats == last_response

        last_response = rxu_mats

        mats = rxu_mats.map do
          {
            style_id: Style.where(style: _1[:style]).pluck(:id).first,
            material_code: _1[:materialCode],
            tint_code: _1[:tintCode],
            treat_code: _1[:treatCode],
            active: true,
            material_description: _1[:materialDesc]
          }
        end.reject { _1[:style_id].nil? }

        StyleMaterial.quietly do
          mats.each do |mat|
            material = StyleMaterial.unscope(:where).where(style_id: mat[:style_id], material_code: mat[:material_code], tint_code: mat[:tint_code], treat_code: mat[:treat_code]).first_or_initialize
            material.assign_attributes(mat)
            material.save
            style_ids << material.id
          end
        end

        offset += SyncStatus::LIMIT
      end

      StyleMaterial.quietly do
        StyleMaterial.where.not(id: style_ids).update_all(active: false, updated_at: Time.now)
      end
    end
  end
end
